BasicBlock

Enum BasicBlock 

pub enum BasicBlock {
    Normal,
    Cleanup,
}
๐Ÿ”ฌThis is a nightly-only experimental API. (custom_mir)
Type representing basic blocks.

All terminators will have this type as a return type. It helps achieve some type safety.

Variants



Normal

๐Ÿ”ฌThis is a nightly-only experimental API. (custom_mir)

A non-cleanup basic block.



Cleanup

๐Ÿ”ฌThis is a nightly-only experimental API. (custom_mir)

A basic block that lies on an unwind path.