pub enum BasicBlock {
Normal,
Cleanup,
}๐ฌThis is a nightly-only experimental API. (
custom_mir)Expand description
Type representing basic blocks.
All terminators will have this type as a return type. It helps achieve some type safety.
Variants
Normal
๐ฌThis is a nightly-only experimental API. (
custom_mir)A non-cleanup basic block.
Cleanup
๐ฌThis is a nightly-only experimental API. (
custom_mir)A basic block that lies on an unwind path.